@@ -84,15 +84,21 @@
 #'   inside the logarithms to avoid computing logarithms of zero.}
 #'
 #' \item{\code{nc}}{Number of threads used in the multithreaded
-#'   computations. Note that the multithreading relies on forking hence
-#'   is not available on Windows; will return an error on Windows unless
-#'   \code{nc = 1}. See \code{\link[parallel]{mclapply}} for
-#'   details. Also note that if R is installed with a multithreading
-#'   numerical linear algebra library (e.g., OpenBLAS), for best
-#'   performance the number of threads used by the linear algebra
-#'   library should be set to 1 (i.e., no multithreading). This can be
-#'   controlled for example using the RhpcBLASctl package.}
+#'   computations. This controls both (a) the number of RcppParallel
+#'   threads used to fit the factors in the Poisson models, and (b)
+#'   the number of cores used in \code{\link[parallel]{mclapply}} for
+#'   the MCMC simulation step. Note that mclapply relies on forking
+#'   hence is not available on Windows; will return an error on
+#'   Windows unless \code{nc = 1}. Also note that setting \code{nc >
+#'   1} copies the contents of memory \code{nc} times, which can lead
+#'   to poor performance if the total resident memory required exceeds
+#'   available physical memory.}
 #'
+#' \item{\code{nc.blas}}{Number of threads used in the numerical
+#'   linear algebra library (e.g., OpenBLAS), if available. For best
+#'   performance, we recommend setting this to 1 (i.e., no
+#'   multithreading).}
+#' 
 #' \item{\code{nsplit}}{The number of data splits used in the
 #'   multithreaded computations (only relevant when \code{nc > 1}). More
 #'   splits increase the granularity of the progress bar, but can also
@@ -230,6 +236,8 @@
 #' @importFrom stats rnorm
 #' @importFrom stats runif
 #' @importFrom ashr ash
+#' @importFrom RhpcBLASctl blas_set_num_threads
+#' @importFrom RhpcBLASctl blas_get_num_procs
 #'
 #' @export
 #' 
@@ -245,9 +253,9 @@ de_analysis <- function (fit, X, s = rowSums(X), pseudocount = 0.01,
     L <- fit
     if (any((rowSums(L) - 1) > 1e-15))
       warning("\"fit\" is a matrix but may not be topic proportions matrix; ",
-              "rowSums(X) should be a vector of all ones")
+              "rowSums(fit) should be a vector of all ones")
     m <- ncol(X)
-    k <- ncol(fit)
+    k <- ncol(L)
     F <- matrix(1,m,k)
     rownames(F) <- colnames(X)
     colnames(F) <- colnames(L)
@@ -357,6 +365,8 @@ de_analysis <- function (fit, X, s = rowSums(X), pseudocount = 0.01,
   D <- matrix(rnorm(ns*k),ns,k)
   U <- matrix(runif(ns*k),ns,k)
   M <- matrix(sample(k,ns*k,replace = TRUE),ns,k) - 1
+  ncb <- blas_get_num_procs()
+  blas_set_num_threads(control$nc.blas)
   if (nc == 1)
     out <- compute_lfc_stats(X,F,L,f0,D,U,M,lfc.stat,control$conf.level,
                              control$rw,control$eps,verbose)
@@ -366,6 +376,7 @@ de_analysis <- function (fit, X, s = rowSums(X), pseudocount = 0.01,
                                        control$eps,control$nc,control$nsplit,
                                        verbose)
   }
+  blas_set_num_threads(ncb)
   if (any(out$ar == 0))
     warning("One or more MCMC simulations yielded acceptance rates of zero; ",
             "consider increasing the number of Monte Carlo samples ",
@@ -462,6 +473,7 @@ de_analysis_control_default <- function()
        rw         = 0.3,
        eps        = 1e-15,
        nc         = 1,
+       nc.blas    = 1,
        nsplit     = 100)
 
 # Select genes based on a de_analysis result. Input "de" is an object
